package com.ruoyi.programManagement.controller;

import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.programManagement.entity.request.BAdministrativeDistrictRequest;
import com.ruoyi.programManagement.entity.request.BAdministrativeTreeRequest;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.programManagement.domain.BAdministrativeDivision;
import com.ruoyi.programManagement.service.IBAdministrativeDivisionService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

import javax.annotation.Resource;

/**
 * 行政区划Controller
 *
 * @author ruoyi
 * @since 2023-12-12
 */
@Api(tags = "行政区划")
@RestController
@RequestMapping("/pharmaceuticals/division")
public class BAdministrativeDivisionController extends BaseController {
    @Resource
    private IBAdministrativeDivisionService bAdministrativeDivisionService;

    /**
     * 查询行政区划列表
     */
    @ApiOperation(value = "查询行政区划列表", response = BAdministrativeDivision.class)
    @GetMapping("/list")
    public TableDataInfo list(BAdministrativeDivision bAdministrativeDivision) {
        startPage();
        List<BAdministrativeDivision> list = bAdministrativeDivisionService.selectBAdministrativeDivisionList(bAdministrativeDivision);
        return getDataTable(list);
    }

    /**
     * 导出行政区划列表
     */
    @ApiOperation(value = "导出行政区划列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BAdministrativeDivision bAdministrativeDivision) {
        List<BAdministrativeDivision> list = bAdministrativeDivisionService.selectBAdministrativeDivisionList(bAdministrativeDivision);
        ExcelUtil<BAdministrativeDivision> util = new ExcelUtil<BAdministrativeDivision>(BAdministrativeDivision.class);
        util.exportExcel(response, list, "行政区划数据");
    }

    /**
     * 获取行政区划详细信息
     */
    @ApiOperation(value = " 获取行政区划详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bAdministrativeDivisionService.selectBAdministrativeDivisionById(id));
    }

    /**
     * 新增行政区划
     */
    @ApiOperation(value = " 新增行政区划")
    @PostMapping
    public AjaxResult add(@RequestBody BAdministrativeDivision bAdministrativeDivision) {
        return toAjax(bAdministrativeDivisionService.insertBAdministrativeDivision(bAdministrativeDivision));
    }

    /**
     * 修改行政区划
     */
    @ApiOperation(value = " 修改行政区划")
    @PutMapping
    public AjaxResult edit(@RequestBody BAdministrativeDivision bAdministrativeDivision) {
        return toAjax(bAdministrativeDivisionService.updateBAdministrativeDivision(bAdministrativeDivision));
    }

    /**
     * 删除行政区划
     */
    @ApiOperation(value = " 删除行政区划")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bAdministrativeDivisionService.deleteBAdministrativeDivisionByIds(ids));
    }

    /**
     * 行政区划树结构
     */
    @ApiOperation(value = "行政区划树结构")
    @GetMapping("/tree")
    public AjaxResult tree() {
        //区划list
        List<BAdministrativeDistrictRequest> list = bAdministrativeDivisionService.selectBycountyList();
        //乡镇list
        List<BAdministrativeTreeRequest> listsub = bAdministrativeDivisionService.selectByDistctList();
        List<BAdministrativeDistrictRequest> cascadingSelectData = new ArrayList<>();
        for (BAdministrativeDistrictRequest item1 : list) {
            BAdministrativeDistrictRequest parentDto = new BAdministrativeDistrictRequest(item1.getDistrictCode(), item1.getDistrict());
            for (BAdministrativeTreeRequest item2 : listsub) {
                if (item2.getCountyCode() != null && !item2.getCountyCode().equals("")) {
                    if (item2.getCountyCode().substring(0, 6).equals(item1.getDistrictCode())) {
                        BAdministrativeTreeRequest childDto = new BAdministrativeTreeRequest(item2.getCounty(), item2.getCountyCode(), item2.getSort());
                        parentDto.addChild(childDto);

                    }
                }
            }
            cascadingSelectData.add(parentDto);
        }
        return success(cascadingSelectData);
    }
}
