package com.ruoyi.programManagement.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.programManagement.entity.SzsEnterpriseInformation;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;

import com.ruoyi.programManagement.service.ISzsEnterpriseInformationService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 省-企业基本信息Controller
 * 
 * @author ruoyi
 * @date 2023-10-17
 */
@Api(tags = "省-企业基本信息")
@RestController
@RequestMapping("/pharmaceuticals/info")
public class SzsEnterpriseInformationController extends BaseController
{
    @Autowired
    private ISzsEnterpriseInformationService szsEnterpriseInformationService;

    /**
     * 查询省-企业基本信息列表
     */
    @ApiOperation("查询省-企业基本信息列表")
    @GetMapping("/list")
    public TableDataInfo list(SzsEnterpriseInformation szsEnterpriseInformation)
    {
        startPage();
        List<SzsEnterpriseInformation> list = szsEnterpriseInformationService.selectSzsEnterpriseInformationList(szsEnterpriseInformation);
        return getDataTable(list);
    }

    /**
     * 导出省-企业基本信息列表
     */

    @PostMapping("/export")
    public void export(HttpServletResponse response, SzsEnterpriseInformation szsEnterpriseInformation)
    {
        List<SzsEnterpriseInformation> list = szsEnterpriseInformationService.selectSzsEnterpriseInformationList(szsEnterpriseInformation);
        ExcelUtil<SzsEnterpriseInformation> util = new ExcelUtil<SzsEnterpriseInformation>(SzsEnterpriseInformation.class);
        util.exportExcel(response, list, "省-企业基本信息数据");
    }

    /**
     * 获取省-企业基本信息详细信息
     */

    @GetMapping(value = "/{ID}")
    public AjaxResult getInfo(@PathVariable("ID") String ID)
    {
        return success(szsEnterpriseInformationService.selectSzsEnterpriseInformationByID(ID));
    }

    /**
     * 新增省-企业基本信息
     */

    @PostMapping
    public AjaxResult add(@RequestBody SzsEnterpriseInformation szsEnterpriseInformation)
    {
        return toAjax(szsEnterpriseInformationService.insertSzsEnterpriseInformation(szsEnterpriseInformation));
    }

    /**
     * 修改省-企业基本信息
     */

    @PutMapping
    public AjaxResult edit(@RequestBody SzsEnterpriseInformation szsEnterpriseInformation)
    {
        return toAjax(szsEnterpriseInformationService.updateSzsEnterpriseInformation(szsEnterpriseInformation));
    }

    /**
     * 删除省-企业基本信息
     */

	@DeleteMapping("/{IDs}")
    public AjaxResult remove(@PathVariable String[] IDs)
    {
        return toAjax(szsEnterpriseInformationService.deleteSzsEnterpriseInformationByIDs(IDs));
    }
}
